pyxml2pdf - Creating PDF tables from XML
========================================

Convert XML input to PDF table. Since we forked the `upstream <https://github
.com/kuras120/XMLToPDFConverter>`_ this project has generalized quite a bit on the
generation of a multipage PDF file containing a table with subtables each containing
a subset of the xml tags based on the texts of some of their children tags.

For the *pyxml2pdf* homepage go to `GitHub <https://github.com/BjoernLudwigPTB/
pyxml2pdf>`_.

*pyxml2pdf* is written in Python 3 and currently requires Python 3.6 or later.

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    pyxml2pdf.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
